@@ -1,8 +1,3 @@
-#: E101 W191
-for a in 'abc':
-    for b in 'xyz':
-        print a  # indented with 8 spaces
-        print b  # indented with 1 tab
 #: E101 E122 W191 W191
 if True:
     pass
@@ -41,4 +36,10 @@ def test_keys(self):
         u'Norrbotten',
         u'V\xe4sterbotten',
     ])
-#:
+
+
+#: E101 W191
+if True:
+    print("""
+	tab at start of this line
+""")
