@@ -8,10 +8,10 @@ if not header or header[:6] != 'bytes=':
 a = False
 b = True
 #: E702
-import bdist_egg
+print(1)
 bdist_egg.write_safety_flag(cmd.egg_info, safe)
 #: E703
-import shlex
+print(1)
 #: E702 E703
 del a[:]
 a.append(42)
